==> xabacus_7.0.6.orig.tar.gz: xabacus-7.0.6/Abacus.h <==
/*-
# X-BASED ABACUS
#
#  Abacus.h
#
###
#
#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
#
#  Abacus demo and neat pointers from
#  Copyright (c) 1991 - 1998	Luis Fernandes, elf@ee.ryerson.ca
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Abacus */

#ifndef _XtAbacus_h
#define _XtAbacus_h

/***********************************************************************
 *
 * Abacus Widget
 *
 ***********************************************************************/

#if 0
/* These are not ready for prime-time. */
#define QUARTER_PERCENT 1
#define VERTICAL 1
#endif

#ifndef WINVER
#define XtNselectCallback ((char *) "selectCallback")
#define XtNrails ((char *) "rails")
#define XtNbase ((char *) "base")
#define XtNdisplayBase ((char *) "displayBase")
#define XtNvertical ((char *) "vertical")
#define XtNsign ((char *) "sign")
#define XtNquarter ((char *) "quarter")
#define XtNquarterPercent ((char *) "quarterPercent")
#define XtNmode ((char *) "mode")
#define XtNformat ((char *) "format")
#define XtNromanNumerals ((char *) "romanNumerals")
#define XtNtopNumber ((char *) "topNumber")
#define XtNtopOrient ((char *) "topOrient")
#define XtNtopFactor ((char *) "topFactor")
#define XtNtopSpaces ((char *) "topSpaces")
#define XtNbottomNumber ((char *) "bottomNumber")
#define XtNbottomOrient ((char *) "bottomOrient")
#define XtNbottomFactor ((char *) "bottomFactor")
#define XtNbottomSpaces ((char *) "bottomSpaces")
#define XtNframeColor ((char *) "frameColor")
#define XtNrailColor ((char *) "railColor")
#define XtNbeadColor ((char *) "beadColor")
#define XtNbeadBorder ((char *) "beadBorder")
#define XtNmono ((char *) "mono")
#define XtNreverse ((char *) "reverse")
#define XtNdelay ((char *) "delay")
#define XtNbuffer ((char *) "buffer")
#define XtNscript ((char *) "script")
#define XtNdemo ((char *) "demo")
#define XtNdecimalPosition ((char *) "decimalPosition")
#define XtNmenu ((char *) "menu")
#define XtNdemoPath ((char *) "demoPath")
#define XtNdemoFont ((char *) "demoFont")
#define XtNdemoForeground ((char *) "demoForeground")
#define XtNdemoBackground ((char *) "demoBackground")
#define XtNdeck ((char *) "deck")
#define XtNrail ((char *) "rail")
#define XtNnumber ((char *) "number")
#define XtNframed ((char *) "framed")
#define XtNslot ((char *) "slot")
#define XtNdiamond ((char *) "diamond")
#define XtNaux ((char *) "aux")
#define XtNmathBuffer ((char *) "mathBuffer")
#define XtCRails ((char *) "Rails")
#define XtCSpaces ((char *) "Spaces")
#define XtCBase ((char *) "Base")
#define XtCDisplayBase ((char *) "DisplayBase")
#define XtCVertical ((char *) "Vertical")
#define XtCSign ((char *) "Sign")
#define XtCQuarter ((char *) "Quarter")
#define XtCQuarterPercent ((char *) "QuarterPercent")
#define XtCMode ((char *) "Mode")
#define XtCFormat ((char *) "Format")
#define XtCRomanNumerals ((char *) "RomanNumerals")
#define XtCTopNumber ((char *) "TopNumber")
#define XtCTopFactor ((char *) "TopFactor")
#define XtCTopOrient ((char *) "TopOrient")
#define XtCTopSpaces ((char *) "TopSpaces")
#define XtCBottomNumber ((char *) "BottomNumber")
#define XtCBottomFactor ((char *) "BottomFactor")
#define XtCBottomOrient ((char *) "BottomOrient")
#define XtCBottomSpaces ((char *) "BottomSpaces")
#define XtCFrameColor ((char *) "FrameColor")
#define XtCRailColor ((char *) "RailColor")
#define XtCBeadColor ((char *) "BeadColor")
#define XtCBeadBorder ((char *) "BeadBorder")
#define XtCMono ((char *) "Mono")
#define XtCReverse ((char *) "Reverse")
#define XtCDelay ((char *) "Delay")
#define XtCBuffer ((char *) "Buffer")
#define XtCScript ((char *) "Script")
#define XtCDemo ((char *) "Demo")
#define XtCDecimalPosition ((char *) "DecimalPosition")
#define XtCMenu ((char *) "Menu")
#define XtCDemoPath ((char *) "DemoPath")
#define XtCDemoFont ((char *) "DemoFont")
#define XtCDemoForeground ((char *) "DemoForeground")
#define XtCDemoBackground ((char *) "DemoBackground")
#define XtCDeck ((char *) "Deck")
#define XtCRail ((char *) "Rail")
#define XtCNumber ((char *) "Number")
#define XtCFramed ((char *) "Framed")
#define XtCSlot ((char *) "Slot")
#define XtCDiamond ((char *) "Diamond")
#define XtCAux ((char *) "Aux")
#define XtCMathBuffer ((char *) "MathBuffer")
typedef struct _AbacusClassRec *AbacusWidgetClass;
typedef struct _AbacusDemoClassRec *AbacusDemoWidgetClass;

extern WidgetClass abacusWidgetClass;
extern WidgetClass abacusDemoWidgetClass;

typedef struct {
	XEvent     *event;
	int         reason;
	char       *buffer, *mathBuffer;
	int         aux, deck, rail, number;
} abacusCallbackStruct;
#endif

#define ABACUS_BASE_DEFAULT (-12)
#define ABACUS_DEMO_DEFAULT (-11)
#define ABACUS_HIDE (-10)
#define ABACUS_CLEAR_QUERY (-9)
#define ABACUS_CALC (-8)
#define ABACUS_MORE (-7)
#define ABACUS_REPEAT (-6)
#define ABACUS_NEXT (-5)
#define ABACUS_DEMO (-4)
#define ABACUS_CLEAR (-3)
#define ABACUS_SCRIPT (-2)
#define ABACUS_IGNORE (-1)
#define ABACUS_MOVE 0
#define ABACUS_DEC 1
#define ABACUS_INC 2
#define ABACUS_VERTICAL 3
#define ABACUS_ROMANNUMERAL 4
#define ABACUS_SIGN 5
#define ABACUS_QUARTER 6
#define ABACUS_QUARTERPERCENT 7
#define ABACUS_FORMAT 8

#ifdef WINVER
#ifdef UNIXDELIM
#define CURRENTDELIM "./"
#define FINALDELIM "/"
#else
#define CURRENTDELIM ".\\"
#define FINALDELIM "\\"
#endif
#else
#ifdef VMS
#define CURRENTDELIM "[]"
#define FINALDELIM ""
#else
#define CURRENTDELIM "./"
#define FINALDELIM "/"
#endif
#endif
#define PRIMARY 0
#define LEFTAUX 1
#define RIGHTAUX 2
#define MINRAILS 1
#define MINDEMORAILS 3
#define DEFAULTRAILS 13
#define DEFAULTTOPSPACES 2
#define DEFAULTBOTTOMSPACES 2
#define DEFAULTTOPNUMBER 2
#define DEFAULTBOTTOMNUMBER 5
#define DEFAULTTOPFACTOR 5
#define DEFAULTBOTTOMFACTOR 1
#define DEFAULTTOPORIENT TRUE
#define DEFAULTBOTTOMORIENT FALSE
#ifdef MONOTEST
#define DEFAULTMONO TRUE
#else
#define DEFAULTMONO FALSE
#endif
#define DEFAULTREVERSE FALSE
#define CHINESE 0
#define JAPANESE 1
#define KOREAN 2
#define ROMAN 3
#define RUSSIAN 4
#define OTHER 5
#define MAXMODES 6
#define MINBASE 2 /* Base 1 is rediculous :) */
#define MAXBASE 36 /* 10 numbers + 26 letters (ASCII) */
#define DEFAULTBASE 10
#define QUARTERS 4
#define QUARTERPERCENTS 4

/* Migrate to Locale */
#define MAX_FRACTION_DIGITS 2

typedef struct _AbacusRec *AbacusWidget;
typedef struct _AbacusRec *AbacusDemoWidget;

extern void intCat(char ** string, const char * var1, const int var2);
#if 0
extern void stringCat(char ** string, const char * var1, const char * var2);
#endif

#endif /* _XtAbacus_h */
/* DON'T ADD STUFF AFTER THIS #endif */

==> xabacus_7.1.3.orig.tar.gz: xabacus-7.1.3/Abacus.h <==
/*-
# X-BASED ABACUS
#
#  Abacus.h
#
###
#
#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
#
#  Abacus demo and neat pointers from
#  Copyright (c) 1991 - 1998	Luis Fernandes, elf@ee.ryerson.ca
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Abacus */

#ifndef _XtAbacus_h
#define _XtAbacus_h

/***********************************************************************
 *
 * Abacus Widget
 *
 ***********************************************************************/

#if 0
/* These are not ready for prime-time. */
#define QUARTER_PERCENT 1
#define VERTICAL 1
#endif

#ifndef WINVER
#define XtNselectCallback ((char *) "selectCallback")
#define XtNrails ((char *) "rails")
#define XtNbase ((char *) "base")
#define XtNdisplayBase ((char *) "displayBase")
#define XtNvertical ((char *) "vertical")
#define XtNsign ((char *) "sign")
#define XtNquarter ((char *) "quarter")
#define XtNquarterPercent ((char *) "quarterPercent")
#define XtNmode ((char *) "mode")
#define XtNformat ((char *) "format")
#define XtNromanNumerals ((char *) "romanNumerals")
#define XtNtopNumber ((char *) "topNumber")
#define XtNtopOrient ((char *) "topOrient")
#define XtNtopFactor ((char *) "topFactor")
#define XtNtopSpaces ((char *) "topSpaces")
#define XtNbottomNumber ((char *) "bottomNumber")
#define XtNbottomOrient ((char *) "bottomOrient")
#define XtNbottomFactor ((char *) "bottomFactor")
#define XtNbottomSpaces ((char *) "bottomSpaces")
#define XtNframeColor ((char *) "frameColor")
#define XtNrailColor ((char *) "railColor")
#define XtNbeadColor ((char *) "beadColor")
#define XtNbeadBorder ((char *) "beadBorder")
#define XtNmono ((char *) "mono")
#define XtNreverse ((char *) "reverse")
#define XtNdelay ((char *) "delay")
#define XtNsound ((char *) "sound")
#define XtNbumpSound ((char *) "bumpSound")
#define XtNmoveSound ((char *) "moveSound")
#define XtNbuffer ((char *) "buffer")
#define XtNscript ((char *) "script")
#define XtNdemo ((char *) "demo")
#define XtNdecimalPosition ((char *) "decimalPosition")
#define XtNmenu ((char *) "menu")
#define XtNdemoPath ((char *) "demoPath")
#define XtNdemoFont ((char *) "demoFont")
#define XtNdemoForeground ((char *) "demoForeground")
#define XtNdemoBackground ((char *) "demoBackground")
#define XtNdeck ((char *) "deck")
#define XtNrail ((char *) "rail")
#define XtNnumber ((char *) "number")
#define XtNframed ((char *) "framed")
#define XtNslot ((char *) "slot")
#define XtNdiamond ((char *) "diamond")
#define XtNaux ((char *) "aux")
#define XtNmathBuffer ((char *) "mathBuffer")
#define XtCRails ((char *) "Rails")
#define XtCSpaces ((char *) "Spaces")
#define XtCBase ((char *) "Base")
#define XtCDisplayBase ((char *) "DisplayBase")
#define XtCVertical ((char *) "Vertical")
#define XtCSign ((char *) "Sign")
#define XtCQuarter ((char *) "Quarter")
#define XtCQuarterPercent ((char *) "QuarterPercent")
#define XtCMode ((char *) "Mode")
#define XtCFormat ((char *) "Format")
#define XtCRomanNumerals ((char *) "RomanNumerals")
#define XtCTopNumber ((char *) "TopNumber")
#define XtCTopFactor ((char *) "TopFactor")
#define XtCTopOrient ((char *) "TopOrient")
#define XtCTopSpaces ((char *) "TopSpaces")
#define XtCBottomNumber ((char *) "BottomNumber")
#define XtCBottomFactor ((char *) "BottomFactor")
#define XtCBottomOrient ((char *) "BottomOrient")
#define XtCBottomSpaces ((char *) "BottomSpaces")
#define XtCFrameColor ((char *) "FrameColor")
#define XtCRailColor ((char *) "RailColor")
#define XtCBeadColor ((char *) "BeadColor")
#define XtCBeadBorder ((char *) "BeadBorder")
#define XtCMono ((char *) "Mono")
#define XtCReverse ((char *) "Reverse")
#define XtCDelay ((char *) "Delay")
#define XtCSound ((char *) "Sound")
#define XtCBumpSound ((char *) "BumpSound")
#define XtCMoveSound ((char *) "MoveSound")
#define XtCBuffer ((char *) "Buffer")
#define XtCScript ((char *) "Script")
#define XtCDemo ((char *) "Demo")
#define XtCDecimalPosition ((char *) "DecimalPosition")
#define XtCMenu ((char *) "Menu")
#define XtCDemoPath ((char *) "DemoPath")
#define XtCDemoFont ((char *) "DemoFont")
#define XtCDemoForeground ((char *) "DemoForeground")
#define XtCDemoBackground ((char *) "DemoBackground")
#define XtCDeck ((char *) "Deck")
#define XtCRail ((char *) "Rail")
#define XtCNumber ((char *) "Number")
#define XtCFramed ((char *) "Framed")
#define XtCSlot ((char *) "Slot")
#define XtCDiamond ((char *) "Diamond")
#define XtCAux ((char *) "Aux")
#define XtCMathBuffer ((char *) "MathBuffer")
typedef struct _AbacusClassRec *AbacusWidgetClass;
typedef struct _AbacusDemoClassRec *AbacusDemoWidgetClass;

extern WidgetClass abacusWidgetClass;
extern WidgetClass abacusDemoWidgetClass;

typedef struct {
	XEvent     *event;
	int         reason;
	char       *buffer, *mathBuffer;
	int         aux, deck, rail, number;
} abacusCallbackStruct;
#endif

#define ABACUS_BASE_DEFAULT (-12)
#define ABACUS_DEMO_DEFAULT (-11)
#define ABACUS_HIDE (-10)
#define ABACUS_CLEAR_QUERY (-9)
#define ABACUS_CALC (-8)
#define ABACUS_MORE (-7)
#define ABACUS_REPEAT (-6)
#define ABACUS_NEXT (-5)
#define ABACUS_DEMO (-4)
#define ABACUS_CLEAR (-3)
#define ABACUS_SCRIPT (-2)
#define ABACUS_IGNORE (-1)
#define ABACUS_MOVE 0
#define ABACUS_DEC 1
#define ABACUS_INC 2
#define ABACUS_VERTICAL 3
#define ABACUS_ROMANNUMERAL 4
#define ABACUS_SIGN 5
#define ABACUS_QUARTER 6
#define ABACUS_QUARTERPERCENT 7
#define ABACUS_FORMAT 8

#ifdef WINVER
#ifdef UNIXDELIM
#define CURRENTDELIM "./"
#define FINALDELIM "/"
#else
#define CURRENTDELIM ".\\"
#define FINALDELIM "\\"
#endif
#else
#ifdef VMS
#define CURRENTDELIM "[]"
#define FINALDELIM ""
#else
#define CURRENTDELIM "./"
#define FINALDELIM "/"
#endif
#endif
#define PRIMARY 0
#define LEFTAUX 1
#define RIGHTAUX 2
#define MINRAILS 1
#define MINDEMORAILS 3
#define DEFAULTRAILS 13
#define DEFAULTTOPSPACES 2
#define DEFAULTBOTTOMSPACES 2
#define DEFAULTTOPNUMBER 2
#define DEFAULTBOTTOMNUMBER 5
#define DEFAULTTOPFACTOR 5
#define DEFAULTBOTTOMFACTOR 1
#define DEFAULTTOPORIENT TRUE
#define DEFAULTBOTTOMORIENT FALSE
#ifdef MONOTEST
#define DEFAULTMONO TRUE
#else
#define DEFAULTMONO FALSE
#endif
#define DEFAULTREVERSE FALSE
#define CHINESE 0
#define JAPANESE 1
#define KOREAN 2
#define ROMAN 3
#define RUSSIAN 4
#define OTHER 5
#define MAXFORMATS 5
#define MAXMODES 6
#define MINBASE 2 /* Base 1 is rediculous :) */
#define MAXBASE 36 /* 10 numbers + 26 letters (ASCII) */
#define DEFAULTBASE 10
#define QUARTERS 4
#define QUARTERPERCENTS 4

/* Migrate to Locale */
#define MAX_FRACTION_DIGITS 2

typedef struct _AbacusRec *AbacusWidget;
typedef struct _AbacusRec *AbacusDemoWidget;

extern void intCat(char ** string, const char * var1, const int var2);
#if 0
extern void stringCat(char ** string, const char * var1, const char * var2);
#endif

#endif /* _XtAbacus_h */
/* DON'T ADD STUFF AFTER THIS #endif */
